@@ -87,9 +87,8 @@ int dns_ip4_qualify(stralloc *,stralloc *,const stralloc *);
 int dns_ip6_qualify_rules(stralloc *,stralloc *,const stralloc *,const stralloc *);
 int dns_ip6_qualify(stralloc *,stralloc *,const stralloc *);
 
-#define DNS_IP6_INT 0
-#define DNS_IP6_ARPA 1
-void dns_name6_domain(char *,const char *,int);
+void dns_name6_domain(char *,const char *);
 #define DNS_NAME6_DOMAIN (4*16+11)
+int dns_name6(stralloc *,const char *);
 
 #endif
