@@ -1,12 +1,16 @@
 #ifndef SOCKET_H
 #define SOCKET_H
 
+#include <sys/types.h>
+
 #include "uint16.h"
 #include "uint32.h"
 
 int socket_tcp4(void);
+int socket_tcp4b(void);
 int socket_udp4(void);
 int socket_tcp6(void);
+int socket_tcp6b(void);
 int socket_udp6(void);
 
 #define socket_tcp() socket_tcp4()
@@ -22,10 +26,10 @@ int socket_bind6_reuse(int s,const char* ip,uint16 port,uint32 scope_id);
 int socket_listen(int s,unsigned int backlog);
 int socket_accept4(int s,char* ip,uint16* port);
 int socket_accept6(int s,char* ip,uint16* port,uint32* scope_id);
-int socket_recv4(int s,char* buf,unsigned int len,char* ip,uint16* port);
-int socket_recv6(int s,char* buf,unsigned int len,char* ip,uint16* port,uint32* scope_id);
-int socket_send4(int s,const char* buf,unsigned int len,const char* ip,uint16 port);
-int socket_send6(int s,const char* buf,unsigned int len,const char* ip,uint16 port,uint32 scope_id);
+ssize_t socket_recv4(int s,char* buf,size_t len,char* ip,uint16* port);
+ssize_t socket_recv6(int s,char* buf,size_t len,char* ip,uint16* port,uint32* scope_id);
+ssize_t socket_send4(int s,const char* buf,size_t len,const char* ip,uint16 port);
+ssize_t socket_send6(int s,const char* buf,size_t len,const char* ip,uint16 port,uint32 scope_id);
 int socket_local4(int s,char* ip,uint16* port);
 int socket_local6(int s,char* ip,uint16* port,uint32* scope_id);
 int socket_remote4(int s,char* ip,uint16* port);
@@ -46,6 +50,17 @@ int socket_mchopcount6(int s,char hops);
 int socket_mcloop4(int s,char hops);
 int socket_mcloop6(int s,char hops);
 
+/* please note that these are platform specific.  Do not expect them to
+ * work.  You might still get an accept() signalled even though there is
+ * no data available.  So far, DATAIN is supported on FreeBSD and Linux,
+ * and HTTPIN is supported on FreeBSD. */
+enum defermode {
+  DATAIN,	// only signal accept() if there is data coming in
+  HTTPIN,	// only signal accept() if a HTTP header has come in
+};
+
+void socket_deferaccept(int s,enum defermode mode);
+
 void socket_tryreservein(int s,int size);
 
 const char* socket_getifname(uint32 _interface);
