@@ -1,9 +1,7 @@
 #ifndef STRALLOC_H
 #define STRALLOC_H
 
-#ifdef __dietlibc__
-#include <sys/cdefs.h>
-#endif
+#include <stddef.h>
 #ifndef __pure__
 #define __pure__
 #endif
@@ -16,8 +14,8 @@
 
 typedef struct stralloc {
   char* s;
-  unsigned long int len;
-  unsigned long int a;
+  size_t len;
+  size_t a;
 } stralloc;
 
 /* stralloc_init will initialize a stralloc.
@@ -32,17 +30,17 @@ void stralloc_init(stralloc* sa);
  * bytes of space, copies the old string into the new space, frees the
  * old space, and returns 1. Note that this changes sa.s.  If the
  * allocation fails, stralloc_ready leaves sa alone and returns 0. */
-int stralloc_ready(stralloc* sa,unsigned long int len);
+int stralloc_ready(stralloc* sa,size_t len);
 
 /* stralloc_readyplus is like stralloc_ready except that, if sa is
  * already allocated, stralloc_readyplus adds the current length of sa
  * to len. */
-int stralloc_readyplus(stralloc* sa,unsigned long int len);
+int stralloc_readyplus(stralloc* sa,size_t len);
 
 /* stralloc_copyb copies the string buf[0], buf[1], ..., buf[len-1] into
  * sa, allocating space if necessary, and returns 1. If it runs out of
  * memory, stralloc_copyb leaves sa alone and returns 0. */
-int stralloc_copyb(stralloc* sa,const char* buf,unsigned long int len);
+int stralloc_copyb(stralloc* sa,const char* buf,size_t len);
 
 /* stralloc_copys copies a \0-terminated string from buf into sa,
  * without the \0. It is the same as
@@ -58,7 +56,7 @@ int stralloc_copy(stralloc* sa,const stralloc* sa2);
  * returns 1. If sa is unallocated, stralloc_catb is the same as
  * stralloc_copyb. If it runs out of memory, stralloc_catb leaves sa
  * alone and returns 0. */
-int stralloc_catb(stralloc* sa,const char* in,unsigned long int len);
+int stralloc_catb(stralloc* sa,const char* in,size_t len);
 
 /* stralloc_cats is analogous to stralloc_copys */
 int stralloc_cats(stralloc* sa,const char* in);
@@ -100,10 +98,10 @@ int stralloc_diffs(const stralloc* a,const char* b) __pure__;
 #define stralloc_0(sa) stralloc_append(sa,"")
 
 /* stralloc_catulong0 appends a '0' padded ASCII representation of in */
-int stralloc_catulong0(stralloc* sa,unsigned long int in,unsigned long int n);
+int stralloc_catulong0(stralloc* sa,unsigned long int in,size_t n);
 
 /* stralloc_catlong0 appends a '0' padded ASCII representation of in */
-int stralloc_catlong0(stralloc* sa,signed long int in,unsigned long int n);
+int stralloc_catlong0(stralloc* sa,signed long int in,size_t n);
 
 /* stralloc_free frees the storage associated with sa */
 void stralloc_free(stralloc* sa);
@@ -137,12 +135,12 @@ int buffer_putsaflush(buffer* b,stralloc* sa);
  * data is available. */
 
 /* read token from buffer to stralloc */
-int buffer_get_token_sa(buffer* b,stralloc* sa,const char* charset,unsigned long int setlen);
+int buffer_get_token_sa(buffer* b,stralloc* sa,const char* charset,size_t setlen);
 /* read line from buffer to stralloc */
 int buffer_getline_sa(buffer* b,stralloc* sa);
 
 /* same as buffer_get_token_sa but empty sa first */
-int buffer_get_new_token_sa(buffer* b,stralloc* sa,const char* charset,unsigned long int setlen);
+int buffer_get_new_token_sa(buffer* b,stralloc* sa,const char* charset,size_t setlen);
 /* same as buffer_getline_sa but empty sa first */
 int buffer_getnewline_sa(buffer* b,stralloc* sa);
 
