@@ -12,6 +12,7 @@
 #include <unistd.h>
 #include <stdlib.h>
 #include <errno.h>
+#include <string.h>
 
 static void carp(const char* routine) {
   buffer_puts(buffer_2,routine);
@@ -181,6 +182,16 @@ e404:
   io_wantwrite(s);
 }
 
+void cleanup(int64 socket) {
+  struct http_data*x=io_getcookie(socket);
+  if (x) {
+    array_reset(&x->r);
+    iob_free(&x->iob);
+    free(x->hdrbuf);
+    free(x);
+  }
+}
+
 int main() {
   int s=socket_tcp6();
   uint32 scope_id;
@@ -190,7 +201,6 @@ int main() {
     panic("socket_bind6_reuse");
   if (socket_listen(s,16)==-1)
     panic("socket_listen");
-  io_nonblock(s);
   if (!io_fd(s))
     panic("io_fd");
   io_wantread(s);
@@ -209,7 +219,6 @@ int main() {
 	  buffer_puts(buffer_2," (fd ");
 	  buffer_putulong(buffer_2,n);
 	  buffer_puts(buffer_2,")");
-	  io_nonblock(n);
 	  if (io_fd(n)) {
 	    struct http_data* h=(struct http_data*)malloc(sizeof(struct http_data));
 	    io_wantread(n);
@@ -243,6 +252,7 @@ int main() {
 	  buffer_puts(buffer_2,"): ");
 	  buffer_puterror(buffer_2);
 	  buffer_putnlflush(buffer_2);
+	  cleanup(i);
 	  io_close(i);
 	} else if (l==0) {
 	  if (h) {
@@ -253,6 +263,7 @@ int main() {
 	  buffer_puts(buffer_2,"eof on fd #");
 	  buffer_putulong(buffer_2,i);
 	  buffer_putnlflush(buffer_2);
+	  cleanup(i);
 	  io_close(i);
 	} else if (l>0) {
 	  array_catb(&h->r,buf,l);
@@ -281,8 +292,10 @@ emerge:
 	if (h->keepalive) {
 	  io_dontwantwrite(i);
 	  io_wantread(i);
-	} else
+	} else {
+	  cleanup(i);
 	  io_close(i);
+	}
       }
     }
   }
